
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v6.005.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "Module::Build" => "0.28"
  },
  "dist_abstract" => "Get metadata for files in directories processed by L<BioX::Workflow>",
  "dist_author" => [
    "Jillian Rowe <jillian.e.rowe\@gmail.com>"
  ],
  "dist_name" => "BioX-Workflow-Plugin-FileDetails",
  "dist_version" => "0.09",
  "license" => "perl",
  "module_name" => "BioX::Workflow::Plugin::FileDetails",
  "recursive_test_files" => 1,
  "requires" => {
    "BioX::Workflow" => 0,
    "File::Basename" => 0,
    "File::Details" => 0,
    "File::Find::Rule" => 0,
    "File::Path" => 0,
    "File::Spec" => 0,
    "File::stat" => 0,
    "List::Uniq" => 0,
    "Moose::Role" => 0,
    "Number::Bytes::Human" => 0,
    "Time::localtime" => 0,
    "perl" => "5.008005"
  },
  "script_files" => [
    "script/filedetails.pl"
  ],
  "test_requires" => {
    "Test::More" => "0.96"
  }
);


my %fallback_build_requires = (
  "Module::Build" => "0.28",
  "Test::More" => "0.96"
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
